==> extension_vulkan_loader-1.4.304.tar.xz: extension_vulkan_loader-1.4.304/scripts/vulkan_loader.sh <==
DESCRIPTION="The Vulkan-Headers package contains a set of header files necessary to build and link applications against the Vulkan API."
# blank
# The 

# Contents
# Installed Programs: None
# Installed Libraries: None
# Installed DRI Driver Stubs: None
# Installed VA-API Drivers: None
# Installed GBM Backends: None
# Installed VDPAU Drivers: None
# Installed Vulkan Drivers: None
# Installed Directories: None

# Short Descriptions
# None

# Required
# None

# Recommended
# None

# Recommended_Runtime
# None

# Optional
# None

# Optional features and packages
# None

# Optional input plugins
# None

# Optional mux/demux plugins

# None

# Optional codec plugins
# None

# Optional video plugins
# None

# Optional audio plugins
# None

# Optional interface plugins
# None

# Optional visualisations and video filter plugins
# None

# Optional service discovery plugins
# None

# Miscellaneous options
# None

# Optional_Documentation
# None

# Optional_Testing
# None

EXT_VERSION=$(basename $PKG_VULKAN_LOADER .tar.gz | cut -d "-" -f 3) 

mkdir build &&
cd    build &&

cmake -D CMAKE_INSTALL_PREFIX=/usr   \
      -D CMAKE_BUILD_TYPE=Release    \
      -D CMAKE_SKIP_INSTALL_RPATH=ON \
      -G Ninja .. &&
ninja

# As root:
ninja install

if $MULTILIB
then
	rm -rf *
	ASFLAGS+=" --32" CFLAGS+=" -m32"       \
	CXXFLAGS+=" -m32"                      \
	PKG_CONFIG_PATH=/usr/lib32/pkgconfig   \
	cmake -D CMAKE_INSTALL_PREFIX=/usr     \
		  -D CMAKE_INSTALL_LIBDIR=lib32    \
		  -D CMAKE_BUILD_TYPE=Release      \
		  -D CMAKE_SKIP_INSTALL_RPATH=ON   \
		  -G Ninja ..
	ninja
	DESTDIR=$PWD/DESTDIR ninja install
	cp -vr DESTDIR/usr/lib32/* /usr/lib32
	rm -rf DESTDIR
	/sbin/ldconfig
fi
if $MULTILIB_X32
then
	rm -rf *
	ASFLAGS+=" --x32" CFLAGS+=" -mx32"     \
	CXXFLAGS+=" -mx32"                     \
	PKG_CONFIG_PATH=/usr/libx32/pkgconfig  \
	cmake -D CMAKE_INSTALL_PREFIX=/usr     \
		  -D CMAKE_INSTALL_LIBDIR=libx32   \
		  -D CMAKE_BUILD_TYPE=Release      \
		  -D CMAKE_SKIP_INSTALL_RPATH=ON   \
		  -G Ninja ..
	ninja
	DESTDIR=$PWD/DESTDIR ninja install
	cp -vr DESTDIR/usr/libx32/* /usr/libx32
	rm -rf DESTDIR
	/sbin/ldconfig
fi

update_version_list $PKG_VULKAN_LOADER

==> extension_vulkan_loader-1.4.315.tar.xz: extension_vulkan_loader-1.4.315/scripts/vulkan_loader.sh <==
DESCRIPTION="The Vulkan-Headers package contains a set of header files necessary to build and link applications against the Vulkan API."
# blank
# The 

# Contents
# Installed Programs: None
# Installed Libraries: None
# Installed DRI Driver Stubs: None
# Installed VA-API Drivers: None
# Installed GBM Backends: None
# Installed VDPAU Drivers: None
# Installed Vulkan Drivers: None
# Installed Directories: None

# Short Descriptions
# None

# Required
# None

# Recommended
# None

# Recommended_Runtime
# None

# Optional
# None

# Optional features and packages
# None

# Optional input plugins
# None

# Optional mux/demux plugins

# None

# Optional codec plugins
# None

# Optional video plugins
# None

# Optional audio plugins
# None

# Optional interface plugins
# None

# Optional visualisations and video filter plugins
# None

# Optional service discovery plugins
# None

# Miscellaneous options
# None

# Optional_Documentation
# None

# Optional_Testing
# None

EXT_VERSION=$(basename $PKG_VULKAN_LOADER .tar.gz | cut -d "v" -f 2) 

mkdir build &&
cd    build &&

cmake -D CMAKE_INSTALL_PREFIX=/usr   \
      -D CMAKE_BUILD_TYPE=Release    \
      -D CMAKE_SKIP_INSTALL_RPATH=ON \
      -G Ninja .. &&
ninja

# As root:
ninja install

if $MULTILIB
then
	rm -rf *
	ASFLAGS+=" --32" CFLAGS+=" -m32"       \
	CXXFLAGS+=" -m32"                      \
	PKG_CONFIG_PATH=/usr/lib32/pkgconfig   \
	cmake -D CMAKE_INSTALL_PREFIX=/usr     \
		  -D CMAKE_INSTALL_LIBDIR=lib32    \
		  -D CMAKE_BUILD_TYPE=Release      \
		  -D CMAKE_SKIP_INSTALL_RPATH=ON   \
		  -G Ninja ..
	ninja
	DESTDIR=$PWD/DESTDIR ninja install
	cp -vr DESTDIR/usr/lib32/* /usr/lib32
	rm -rf DESTDIR
	/sbin/ldconfig
fi
if $MULTILIB_X32
then
	rm -rf *
	ASFLAGS+=" --x32" CFLAGS+=" -mx32"     \
	CXXFLAGS+=" -mx32"                     \
	PKG_CONFIG_PATH=/usr/libx32/pkgconfig  \
	cmake -D CMAKE_INSTALL_PREFIX=/usr     \
		  -D CMAKE_INSTALL_LIBDIR=libx32   \
		  -D CMAKE_BUILD_TYPE=Release      \
		  -D CMAKE_SKIP_INSTALL_RPATH=ON   \
		  -G Ninja ..
	ninja
	DESTDIR=$PWD/DESTDIR ninja install
	cp -vr DESTDIR/usr/libx32/* /usr/libx32
	rm -rf DESTDIR
	/sbin/ldconfig
fi

update_version_list Vulkan_Loader-$EXT_VERSION
